@@ -1,5 +1,5 @@
 /* BlinkenLib
- * version 0.1.1 date 2006-10-17
+ * version 0.1.2 date 2008-08-10
  * Copyright (C) 2004-2006: Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a blinkenarea.org project
@@ -233,7 +233,7 @@ public class BlinkenFrame
           for( c = 0; c < this.channels; c++ )
             new_data[emptyY + y][destI + c] = (byte)((((int)data[skipY + y][srcI + c] & 0xFF) * maxval + this.maxval / 2) / this.maxval);
 	  for( ; c < channels; c++ )
-	    new_data[emptyY + y][destI + c] = data[emptyY + y][srcI + this.channels - 1];
+	    new_data[emptyY + y][destI + c] = new_data[emptyY + y][srcI + this.channels - 1];
 	}
 	else //remove channels: merge leftover channels with last kept channel
 	{
